@@ -528,7 +528,7 @@ class AxesFormatter(object):
                    handle_length: Optional[float] = None,
                    handle_text_pad: Optional[float] = None,
                    border_axes_pad: Optional[float] = None,
-                   column_spacing: Optional[float] = None) -> 'LegendFormatter':
+                   column_spacing: Optional[float] = None) -> LegendFormatter:
         """
         Add a legend to the Axes.
 
